import { Client as PgClient } from "pg";
export declare type ClientOptions = {
    target?: string | null;
    table?: string | null;
};
export declare type Params = {
    id?: any;
    data?: any;
    ops: Options;
};
export declare type Options = {
    table?: string;
    target?: any[];
};
export declare type Methods = "fetch" | "set" | "add" | "subtract" | "push" | "delete" | "has" | "clear" | "drop" | "all" | "type";
export declare class Client {
    protected dbUrl: string;
    protected options: ClientOptions | undefined;
    protected client: PgClient;
    protected tableName: string | undefined;
    /**
     * Whether the database has been connected or not.
     * @see connect
     * @see end
     */
    connected: boolean;
    constructor(dbUrl: string, options?: ClientOptions);
    /**
     * Connects to the database specified when creating the client.
     * @returns void
     * @example await db.connect();
     */
    connect(): Promise<void>;
    /**
     * Ends the connection to the database specified when creating the client.
     * @example await db.end();
     */
    end(): Promise<void>;
    /**
     * Fetches data from a key in the database.
     * @param key any string as a key, allows dot notation
     * @param options any options to be added to the request
     * @returns the data requested
     * @alias get
     * @example const data = await db.fetch("users.1234567890.inventory");
     */
    fetch(key: string, ops?: Options): Promise<any>;
    /**
     * Fetches data from a key in the database.
     * @param key any string as a key, allows dot notation
     * @param options any options to be added to the request
     * @returns the data requested
     * @alias get
     * @example const data = await db.fetch("users.1234567890.inventory");
     */
    get(key: string, ops?: Options): Promise<any>;
    /**
     * Sets new data based on a key in the database.
     * @param key any string as a key, allows dot notation
     * @param value value of the data to be set
     * @param options any options to be added to the request
     * @returns the updated data
     * @example const data = await db.set("users.1234567890.level", 100);
     */
    set(key: string, value: any, ops?: Options): Promise<any>;
    /**
     * Adds a number to a key in the database. If no existing number, it will add to 0.
     * @param key any string as a key, allows dot notation
     * @param value value to add
     * @param options any options to be added to the request
     * @returns the updated data
     * @example const data = await db.add("users.1234567890.level", 1);
     */
    add(key: string, value: any, ops?: Options): Promise<any>;
    /**
     * Subtracts a number to a key in the database. If no existing number, it will subtract to 0.
     * @param key any string as a key, allows dot notation
     * @param value value to subtract
     * @param options any options to be added to the request
     * @returns the updated data
     * @example const data = await db.subtract("users.1234567890.level", 10);
     */
    subtract(key: string, value: any, ops?: Options): Promise<any>;
    /**
     * Push into an array in the database based on the key. If no existing array, it will create one.
     * @param key any string as a key, allows dot notation
     * @param value value to push
     * @param options any options to be added to the request
     * @returns the updated data
     * @example const data = await db.push("users.1234567890.inventory", "Slice of Cheese");
     */
    push(key: string, value: any, ops?: Options): Promise<any>;
    /**
     * Delete an object (or property) in the database.
     * @param key any string as a key, allows dot notation
     * @param options any options to be added to the request
     * @returns `true` if success, if not found `false`
     * @example await db.delete("users.1234567890");
     */
    delete(key: string, ops?: Options): Promise<any>;
    /**
     * Returns a boolean indicating whether an element with the specified key exists or not.
     * @param key any string as a key, allows dot notation
     * @param options any options to be added to the request
     * @returns boolean
     * @alias includes
     * @example const data = await db.has("users.1234567890");
     */
    has(key: string, ops?: Options): Promise<boolean>;
    /**
     * Returns a boolean indicating whether an element with the specified key exists or not.
     * @param key any string as a key, allows dot notation
     * @param options any options to be added to the request
     * @returns boolean
     * @alias has
     * @example const data = await db.has("users.1234567890");
     */
    includes(key: string, ops?: Options): Promise<boolean>;
    /**
     * Deletes all rows from the entire active table.
     * Note: This does not delete the table itself. To delete the table itself along with the rows, use `drop()`.
     * @returns amount of rows deleted
     *
     * @example const data = await db.clear();
     */
    clear(): Promise<number>;
    /**
     * Deletes the entire active table.
     * @returns void
     * @example await db.drop();
     */
    drop(): Promise<any>;
    /**
     * Fetches the entire active table
     * @param options any options to be added to the request
     * @returns entire table as an object
     * @alias fetchAll
     * @example const data = await db.all();
     */
    all(ops?: Options): Promise<any>;
    /**
     * Fetches the entire active table
     * @param options any options to be added to the request
     * @returns entire table as an object
     * @alias all
     * @example const data = await db.all();
     */
    fetchAll(ops?: Options): Promise<any>;
    /**
     * Used to get the type of the value.
     * @param key any string as a key, allows dot notation
     * @param options any options to be added to the request
     * @returns type from `typeof`
     */
    type(key: string, ops?: Options): Promise<"bigint" | "boolean" | "function" | "number" | "object" | "string" | "symbol" | "undefined">;
    private arbitrate;
}
